@@ -301,6 +301,42 @@ public class ZipInputStreamIT extends AbstractIT {
         null, InternalZipConstants.BUFF_SIZE, false, 2);
   }
 
+  @Test
+  public void testExtractZipFileWithNullAesExtraDataRecordThrowsException() throws IOException {
+    expectedException.expect(ZipException.class);
+    expectedException.expectMessage("corrupt AES extra data records");
+
+    extractZipFileWithInputStreams(TestUtils.getTestArchiveFromResources("null-aes-key-strength-in-aes-extra-data-record"),
+        null, InternalZipConstants.BUFF_SIZE, false, 1);
+  }
+
+  @Test
+  public void testExtractZipFileWithFileNameLength0ThrowsException() throws IOException {
+    expectedException.expect(IOException.class);
+    expectedException.expectMessage("Invalid entry name in local file header");
+
+    extractZipFileWithInputStreams(TestUtils.getTestArchiveFromResources("file_name_size_is_0_in_local_file_header"),
+        null, InternalZipConstants.BUFF_SIZE, false, 1);
+  }
+
+  @Test
+  public void testExtractZipFileWithInvalidAesExtraDataRecordThrowsException() throws IOException {
+    expectedException.expect(ZipException.class);
+    expectedException.expectMessage("corrupt AES extra data records");
+
+    extractZipFileWithInputStreams(TestUtils.getTestArchiveFromResources("invalid_aes_extra_data_record_length_in_header"),
+        null, InternalZipConstants.BUFF_SIZE, false, 1);
+  }
+
+  @Test
+  public void testExtractZipFileWhenUnexpectedEofReachedThrowsException() throws IOException {
+    expectedException.expect(IOException.class);
+    expectedException.expectMessage("Unexpected EOF reached when trying to read stream");
+
+    extractZipFileWithInputStreams(TestUtils.getTestArchiveFromResources("unexpected-eof-when-reading-stream"),
+        null, InternalZipConstants.BUFF_SIZE, false, 1);
+  }
+
   private void extractZipFileWithInputStreams(File zipFile, char[] password) throws IOException {
     extractZipFileWithInputStreams(zipFile, password, InternalZipConstants.BUFF_SIZE);
   }
